@@ -26,22 +26,13 @@
 #define EEL_GLIB_EXTENSIONS_H
 
 #include <glib.h>
-#include <gio/gio.h>
 
 /* A gboolean variant for bit fields. */
 typedef guint eel_boolean_bit;
 
-/* Predicate. */
-typedef gboolean (* EelPredicateFunction) (gpointer data,
-					   gpointer callback_data);
-
 /* GList functions. */
 gboolean    eel_g_lists_sort_and_check_for_intersection (GList                **list_a,
 							 GList                **list_b);
-/* GHashTable functions */
-void        eel_g_hash_table_safe_for_each              (GHashTable            *hash_table,
-							 GHFunc                 callback,
-							 gpointer               callback_data);
 
 /* NULL terminated string arrays (strv). */
 gboolean    eel_g_strv_equal                            (char                 **a,
