@@ -22,34 +22,14 @@
 
 static char *used_metadata_names[] =
 {
-    NAUTILUS_METADATA_KEY_LOCATION_BACKGROUND_COLOR,
-    NAUTILUS_METADATA_KEY_LOCATION_BACKGROUND_IMAGE,
-    NAUTILUS_METADATA_KEY_ICON_VIEW_AUTO_LAYOUT,
     NAUTILUS_METADATA_KEY_ICON_VIEW_SORT_BY,
     NAUTILUS_METADATA_KEY_ICON_VIEW_SORT_REVERSED,
-    NAUTILUS_METADATA_KEY_ICON_VIEW_KEEP_ALIGNED,
-    NAUTILUS_METADATA_KEY_ICON_VIEW_LAYOUT_TIMESTAMP,
-    NAUTILUS_METADATA_KEY_DESKTOP_ICON_SIZE,
     NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_COLUMN,
     NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED,
     NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS,
     NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER,
-    NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY,
-    NAUTILUS_METADATA_KEY_WINDOW_SCROLL_POSITION,
-    NAUTILUS_METADATA_KEY_WINDOW_SHOW_HIDDEN_FILES,
-    NAUTILUS_METADATA_KEY_WINDOW_MAXIMIZED,
-    NAUTILUS_METADATA_KEY_WINDOW_STICKY,
-    NAUTILUS_METADATA_KEY_WINDOW_KEEP_ABOVE,
-    NAUTILUS_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR,
-    NAUTILUS_METADATA_KEY_SIDEBAR_BACKGROUND_IMAGE,
-    NAUTILUS_METADATA_KEY_SIDEBAR_BUTTONS,
-    NAUTILUS_METADATA_KEY_ANNOTATION,
-    NAUTILUS_METADATA_KEY_ICON_POSITION,
-    NAUTILUS_METADATA_KEY_ICON_POSITION_TIMESTAMP,
-    NAUTILUS_METADATA_KEY_ICON_SCALE,
     NAUTILUS_METADATA_KEY_CUSTOM_ICON,
     NAUTILUS_METADATA_KEY_CUSTOM_ICON_NAME,
-    NAUTILUS_METADATA_KEY_SCREEN,
     NAUTILUS_METADATA_KEY_EMBLEMS,
     NAUTILUS_METADATA_KEY_DESKTOP_FILE_TRUSTED,
     NULL
