@@ -752,17 +752,8 @@ receive_uris (NautilusTreeViewDragDest *dest,
 
     if (real_action == GDK_ACTION_ASK)
     {
-        if (nautilus_drag_selection_includes_special_link (dest->details->drag_list))
-        {
-            /* We only want to move the trash */
-            action = GDK_ACTION_MOVE;
-        }
-        else
-        {
-            action = GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK;
-        }
-        real_action = nautilus_drag_drop_action_ask
-                          (GTK_WIDGET (dest->details->tree_view), action);
+        action = GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK;
+        real_action = nautilus_drag_drop_action_ask (GTK_WIDGET (dest->details->tree_view), action);
     }
 
     /* We only want to copy external uris */
@@ -890,8 +881,7 @@ receive_dropped_raw (NautilusTreeViewDragDest *dest,
     g_signal_emit (dest, signals[HANDLE_RAW], 0,
                    raw_data, length, drop_target,
                    dest->details->direct_save_uri,
-                   gdk_drag_context_get_selected_action (context),
-                   x, y);
+                   gdk_drag_context_get_selected_action (context));
 
     g_free (drop_target);
 }
@@ -1275,12 +1265,10 @@ nautilus_tree_view_drag_dest_class_init (NautilusTreeViewDragDestClass *class)
                       NULL, NULL,
 
                       g_cclosure_marshal_generic,
-                      G_TYPE_NONE, 5,
+                      G_TYPE_NONE, 3,
                       G_TYPE_POINTER,
                       G_TYPE_STRING,
-                      GDK_TYPE_DRAG_ACTION,
-                      G_TYPE_INT,
-                      G_TYPE_INT);
+                      GDK_TYPE_DRAG_ACTION);
     signals[HANDLE_NETSCAPE_URL] =
         g_signal_new ("handle-netscape-url",
                       G_TYPE_FROM_CLASS (class),
@@ -1289,12 +1277,10 @@ nautilus_tree_view_drag_dest_class_init (NautilusTreeViewDragDestClass *class)
                                        handle_netscape_url),
                       NULL, NULL,
                       g_cclosure_marshal_generic,
-                      G_TYPE_NONE, 5,
+                      G_TYPE_NONE, 3,
                       G_TYPE_STRING,
                       G_TYPE_STRING,
-                      GDK_TYPE_DRAG_ACTION,
-                      G_TYPE_INT,
-                      G_TYPE_INT);
+                      GDK_TYPE_DRAG_ACTION);
     signals[HANDLE_URI_LIST] =
         g_signal_new ("handle-uri-list",
                       G_TYPE_FROM_CLASS (class),
@@ -1303,12 +1289,10 @@ nautilus_tree_view_drag_dest_class_init (NautilusTreeViewDragDestClass *class)
                                        handle_uri_list),
                       NULL, NULL,
                       g_cclosure_marshal_generic,
-                      G_TYPE_NONE, 5,
+                      G_TYPE_NONE, 3,
                       G_TYPE_STRING,
                       G_TYPE_STRING,
-                      GDK_TYPE_DRAG_ACTION,
-                      G_TYPE_INT,
-                      G_TYPE_INT);
+                      GDK_TYPE_DRAG_ACTION);
     signals[HANDLE_TEXT] =
         g_signal_new ("handle-text",
                       G_TYPE_FROM_CLASS (class),
@@ -1317,12 +1301,10 @@ nautilus_tree_view_drag_dest_class_init (NautilusTreeViewDragDestClass *class)
                                        handle_text),
                       NULL, NULL,
                       g_cclosure_marshal_generic,
-                      G_TYPE_NONE, 5,
+                      G_TYPE_NONE, 3,
                       G_TYPE_STRING,
                       G_TYPE_STRING,
-                      GDK_TYPE_DRAG_ACTION,
-                      G_TYPE_INT,
-                      G_TYPE_INT);
+                      GDK_TYPE_DRAG_ACTION);
     signals[HANDLE_RAW] =
         g_signal_new ("handle-raw",
                       G_TYPE_FROM_CLASS (class),
@@ -1331,14 +1313,12 @@ nautilus_tree_view_drag_dest_class_init (NautilusTreeViewDragDestClass *class)
                                        handle_raw),
                       NULL, NULL,
                       g_cclosure_marshal_generic,
-                      G_TYPE_NONE, 7,
+                      G_TYPE_NONE, 5,
                       G_TYPE_POINTER,
                       G_TYPE_INT,
                       G_TYPE_STRING,
                       G_TYPE_STRING,
-                      GDK_TYPE_DRAG_ACTION,
-                      G_TYPE_INT,
-                      G_TYPE_INT);
+                      GDK_TYPE_DRAG_ACTION);
     signals[HANDLE_HOVER] =
         g_signal_new ("handle-hover",
                       G_TYPE_FROM_CLASS (class),
